@@ -2,7 +2,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2008 Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2008/02/13, v3.000.016, collector.pl for ASNMTAP::Asnmtap::Applications::Collector
+# 2008/mm/dd, v3.000.018, collector.pl for ASNMTAP::Asnmtap::Applications::Collector
 # ----------------------------------------------------------------------------------------------------------
 
 use strict;
@@ -23,10 +23,10 @@ use Date::Calc qw(Delta_DHMS);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Time v3.000.016;
+use ASNMTAP::Time v3.000.018;
 use ASNMTAP::Time qw(&get_datetimeSignal &get_csvfiledate &get_csvfiletime &get_logfiledate &get_datetime &get_timeslot);
 
-use ASNMTAP::Asnmtap::Applications::Collector v3.000.016;
+use ASNMTAP::Asnmtap::Applications::Collector v3.000.018;
 use ASNMTAP::Asnmtap::Applications::Collector qw(:APPLICATIONS :COLLECTOR :DBCOLLECTOR);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -42,7 +42,7 @@ use vars qw($opt_H  $opt_M $opt_C $opt_W $opt_A $opt_N $opt_s $opt_S $opt_D $opt
 
 $PROGNAME       = "collector.pl";
 my $prgtext     = "Collector for the '$APPLICATION'";
-my $version     = do { my @r = (q$Revision: 3.000.016$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
+my $version     = do { my @r = (q$Revision: 3.000.018$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -564,20 +564,25 @@ sub call_system {
 
   my $rvOpen;
   my $action = '';
-  my $httpdumpFilename = '';
-  my $debugFilename    = '<NIHIL>';
-  my $dumphttpRename   = '<NIHIL>';
+  my $httpdumpFilename    = '';
+  my $httpdumpFilenameTmp = '';
+  my $debugFilename       = '<NIHIL>';
+  my $dumphttpRename      = '<NIHIL>';
   my ($stdout, $stderr, $exit_value, $signal_num, $dumped_core);
 
   my ($loggedStatus, $returnStatus, $startDate, $startTime, $endDate, $endTime, $msgCommand);
   $startDate = get_csvfiledate();
   $startTime = get_csvfiletime();
   ($msgCommand, undef) = split(/\.pl/, $system_action);
-  $httpdumpFilename = $httpdump . get_datetime() .'-'. $msgCommand .'-'. $uniqueKey if ($dumphttp ne 'N');
+
+  if ($dumphttp ne 'N') {
+    $httpdumpFilename = $httpdump . get_datetime() .'-'. $msgCommand .'-'. $uniqueKey;
+    $httpdumpFilenameTmp = $httpdumpFilename .'.tmp';
+  }
 
   if (-e "$PLUGINPATH/$msgCommand.pl") {
     my $systemAction = "cd $PLUGINPATH; ./$system_action --status=$status --debug=$debug --logging=$logging --asnmtapEnv='$asnmtapEnv'";
-    $systemAction .= " --dumphttp=$httpdumpFilename" if ($dumphttp ne 'N');
+    $systemAction .= " --dumphttp=$httpdumpFilenameTmp" if ($dumphttp ne 'N');
 
     if ($CAPTUREOUTPUT) {
       use IO::CaptureOutput qw(capture_exec);
@@ -624,16 +629,16 @@ sub call_system {
     }
 
     if ($dumphttp ne 'N') {
-      my $httpdumpFilenameKnownError = $httpdumpFilename .'-KnownError';
-      unlink ($httpdumpFilenameKnownError) if (-e "$httpdumpFilenameKnownError");
+      my $httpdumpFilenameTmpKnownError = $httpdumpFilenameTmp .'-KnownError';
+      unlink ($httpdumpFilenameTmpKnownError) if (-e "$httpdumpFilenameTmpKnownError");
 
       if ($dumphttp eq 'A' || (($dumphttp eq 'W' or $dumphttp eq 'C' or $dumphttp eq 'U') && $exit_value > 0)) {
-        if (-e "$httpdumpFilename") {
+        if (-e "$httpdumpFilenameTmp") {
           $debugFilename = $httpdumpFilename .'-'. $dumphttpRename .'.htm';
-          rename("$httpdumpFilename", "$debugFilename");
+          rename("$httpdumpFilenameTmp", "$debugFilename");
         }
       } else {
-        unlink ($httpdumpFilename) if (-e "$httpdumpFilename");
+        unlink ($httpdumpFilenameTmp) if (-e "$httpdumpFilenameTmp");
       }
     }
   } else {
